'use client';

import { useState, FormEvent } from 'react';
import styles from './AuthForms.module.css';
import useAuthStore from '@/store/useAuthStore';
import type { User } from '@/store/useAuthStore';

interface LoginFormData {
  email: string;
  password: string;
}

interface LoginResponse {
  success: boolean;
  message: string;
  token: string;
  user: User;
}

export default function LoginForm() {
  // État du formulaire
  const [formData, setFormData] = useState<LoginFormData>({
    email: '',
    password: ''
  });

  // État des erreurs et du message de succès
  const [error, setError] = useState<string>('');
  const [success, setSuccess] = useState<string>('');
  const [isLoading, setIsLoading] = useState<boolean>(false);

  // Récupération des fonctions du store
  const { setUser, user, isAuthenticated } = useAuthStore();

  // Gestion des changements dans les champs
  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;
    setFormData(prev => ({
      ...prev,
      [name]: value
    }));
  };

  // Soumission du formulaire
  const handleSubmit = async (e: FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    setError('');
    setSuccess('');
    setIsLoading(true);

    try {
      // Validation basique
      if (!formData.email || !formData.password) {
        throw new Error('Veuillez remplir tous les champs');
      }

      // Appel à l'API
      const response = await fetch(`${process.env.NEXT_PUBLIC_API_URL}/api/auth/login`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json'
        },
        body: JSON.stringify(formData)
      });

      const data: LoginResponse = await response.json();

      if (!response.ok) {
        throw new Error(data.message || 'Une erreur est survenue');
      }

      // Mise à jour du store avec les informations de l'utilisateur
      setUser(data.user, data.token);
      setSuccess('Connexion réussie !');

    } catch (err) {
      setError(err instanceof Error ? err.message : 'Une erreur est survenue');
    } finally {
      setIsLoading(false);
    }
  };

  return (
    <div className={styles.formContainer}>
      <h2>Connexion</h2>
      
      <form onSubmit={handleSubmit} className={styles.form}>
        <div className={styles.formGroup}>
          <label htmlFor="email">Email</label>
          <input
            type="email"
            id="email"
            name="email"
            value={formData.email}
            onChange={handleChange}
            placeholder="votre@email.com"
            required
          />
        </div>

        <div className={styles.formGroup}>
          <label htmlFor="password">Mot de passe</label>
          <input
            type="password"
            id="password"
            name="password"
            value={formData.password}
            onChange={handleChange}
            placeholder="Votre mot de passe"
            required
          />
        </div>

        {error && <div className={styles.error}>{error}</div>}
        {success && <div className={styles.success}>{success}</div>}

        <button 
          type="submit" 
          className={styles.submitButton}
          disabled={isLoading}
        >
          {isLoading ? 'Connexion...' : 'Se connecter'}
        </button>
      </form>

      {/* Affichage des informations de l'utilisateur connecté */}
      {isAuthenticated && user && (
        <div className={styles.userInfo}>
          <h3>Utilisateur connecté :</h3>
          <p>Nom : {user.artist_name}</p>
          <p>Email : {user.email}</p>
          <p>Type : {user.user_type}</p>
        </div>
      )}
    </div>
  );
} 