'use client';

import { useState, FormEvent } from 'react';
import styles from './AuthForms.module.css';
import useAuthStore from '@/store/useAuthStore';
import type { User } from '@/store/useAuthStore';

interface RegisterFormData {
  email: string;
  password: string;
  confirmPassword: string;
  artist_name: string;
  user_type: 'artist' | 'venue_owner' | 'partner' | 'admin';
  bio_short?: string;
  bio_long?: string;
}

interface RegisterResponse {
  success: boolean;
  message: string;
  token: string;
  user: User;
}

export default function RegisterForm() {
  // État du formulaire
  const [formData, setFormData] = useState<RegisterFormData>({
    email: '',
    password: '',
    confirmPassword: '',
    artist_name: '',
    user_type: 'artist',
    bio_short: '',
    bio_long: ''
  });

  // État des erreurs et du message de succès
  const [error, setError] = useState<string>('');
  const [success, setSuccess] = useState<string>('');
  const [isLoading, setIsLoading] = useState<boolean>(false);

  // Récupération des fonctions du store
  const { setUser, user, isAuthenticated } = useAuthStore();

  // Gestion des changements dans les champs
  const handleChange = (
    e: React.ChangeEvent<HTMLInputElement | HTMLSelectElement | HTMLTextAreaElement>
  ) => {
    const { name, value } = e.target;
    setFormData(prev => ({
      ...prev,
      [name]: value
    }));
  };

  // Validation du formulaire
  const validateForm = (): string | null => {
    if (!formData.email || !formData.password || !formData.confirmPassword || !formData.artist_name) {
      return 'Veuillez remplir tous les champs obligatoires';
    }
    if (formData.password !== formData.confirmPassword) {
      return 'Les mots de passe ne correspondent pas';
    }
    if (formData.password.length < 8) {
      return 'Le mot de passe doit contenir au moins 8 caractères';
    }
    return null;
  };

  // Soumission du formulaire
  const handleSubmit = async (e: FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    setError('');
    setSuccess('');
    setIsLoading(true);

    // Validation
    const validationError = validateForm();
    if (validationError) {
      setError(validationError);
      setIsLoading(false);
      return;
    }

    try {
      // Préparation des données pour l'API
      const apiData = {
        ...formData,
        confirmPassword: undefined
      };
      delete apiData.confirmPassword;

      // Appel à l'API
      const response = await fetch(`${process.env.NEXT_PUBLIC_API_URL}/api/auth/register`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json'
        },
        body: JSON.stringify(apiData)
      });

      const data: RegisterResponse = await response.json();

      if (!response.ok) {
        throw new Error(data.message || 'Une erreur est survenue');
      }

      // Mise à jour du store avec les informations de l'utilisateur
      setUser(data.user, data.token);
      setSuccess('Inscription réussie !');
      
      // Réinitialisation du formulaire
      setFormData({
        email: '',
        password: '',
        confirmPassword: '',
        artist_name: '',
        user_type: 'artist',
        bio_short: '',
        bio_long: ''
      });

    } catch (err) {
      setError(err instanceof Error ? err.message : 'Une erreur est survenue');
    } finally {
      setIsLoading(false);
    }
  };

  return (
    <div className={styles.formContainer}>
      <h2>Inscription</h2>
      
      <form onSubmit={handleSubmit} className={styles.form}>
        <div className={styles.formGroup}>
          <label htmlFor="email">Email *</label>
          <input
            type="email"
            id="email"
            name="email"
            value={formData.email}
            onChange={handleChange}
            placeholder="votre@email.com"
            required
          />
        </div>

        <div className={styles.formGroup}>
          <label htmlFor="password">Mot de passe *</label>
          <input
            type="password"
            id="password"
            name="password"
            value={formData.password}
            onChange={handleChange}
            placeholder="Minimum 8 caractères"
            required
          />
        </div>

        <div className={styles.formGroup}>
          <label htmlFor="confirmPassword">Confirmer le mot de passe *</label>
          <input
            type="password"
            id="confirmPassword"
            name="confirmPassword"
            value={formData.confirmPassword}
            onChange={handleChange}
            placeholder="Confirmez votre mot de passe"
            required
          />
        </div>

        <div className={styles.formGroup}>
          <label htmlFor="artist_name">Nom d'artiste *</label>
          <input
            type="text"
            id="artist_name"
            name="artist_name"
            value={formData.artist_name}
            onChange={handleChange}
            placeholder="Votre nom d'artiste"
            required
          />
        </div>

        <div className={styles.formGroup}>
          <label htmlFor="user_type">Type d'utilisateur *</label>
          <select
            id="user_type"
            name="user_type"
            value={formData.user_type}
            onChange={handleChange}
            required
          >
            <option value="artist">Artiste</option>
            <option value="venue_owner">Propriétaire de salle</option>
            <option value="partner">Partenaire</option>
            <option value="admin">Administrateur</option>
          </select>
        </div>

        <div className={styles.formGroup}>
          <label htmlFor="bio_short">Courte biographie</label>
          <input
            type="text"
            id="bio_short"
            name="bio_short"
            value={formData.bio_short}
            onChange={handleChange}
            placeholder="Une brève description de vous"
          />
        </div>

        <div className={styles.formGroup}>
          <label htmlFor="bio_long">Biographie détaillée</label>
          <textarea
            id="bio_long"
            name="bio_long"
            value={formData.bio_long}
            onChange={handleChange}
            placeholder="Parlez-nous de vous en détail"
            rows={4}
          />
        </div>

        {error && <div className={styles.error}>{error}</div>}
        {success && <div className={styles.success}>{success}</div>}

        <button 
          type="submit" 
          className={styles.submitButton}
          disabled={isLoading}
        >
          {isLoading ? 'Inscription...' : 'S\'inscrire'}
        </button>
      </form>

      {/* Affichage des informations de l'utilisateur inscrit */}
      {isAuthenticated && user && (
        <div className={styles.userInfo}>
          <h3>Inscription réussie !</h3>
          <p>Nom : {user.artist_name}</p>
          <p>Email : {user.email}</p>
          <p>Type : {user.user_type}</p>
        </div>
      )}
    </div>
  );
} 